
## CATO-CLI - query.groups.whereUsed:
[Click here](https://api.catonetworks.com/documentation/#query-whereUsed) for documentation on this operation.

### Usage for query.groups.whereUsed:

`catocli query groups whereUsed -h`

`catocli query groups whereUsed <json>`

`catocli query groups whereUsed "$(cat < whereUsed.json)"`

`catocli query groups whereUsed '{"groupRefInput": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}'`

#### Operation Arguments for query.groups.whereUsed ####
`accountId` [ID] - (required) N/A 
`groupRefInput` [GroupRefInput] - (required) N/A 
